| chat | R Documentation |
This is a generic interface to all the other chat_ functions that allow
to you pick the provider and the model with a simple string.
chat(
name,
...,
system_prompt = NULL,
params = NULL,
echo = c("none", "output", "all")
)
name |
Provider (and optionally model) name in the form
|
... |
Arguments passed to the provider function. |
system_prompt |
A system prompt to set the behavior of the assistant. |
params |
Common model parameters, usually created by |
echo |
One of the following options:
Note this only affects the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.