View source: R/provider-azure.R
| chat_azure_openai | R Documentation |
The Azure OpenAI server hosts a number of open source models as well as proprietary models from OpenAI.
Built on top of chat_openai_compatible().
chat_azure_openai() supports API keys and the credentials parameter, but
it also makes use of:
Azure service principals (when the AZURE_TENANT_ID, AZURE_CLIENT_ID,
and AZURE_CLIENT_SECRET environment variables are set).
Interactive Entra ID authentication, like the Azure CLI.
Viewer-based credentials on Posit Connect. Requires the connectcreds package.
chat_azure_openai(
endpoint = azure_endpoint(),
model,
params = NULL,
api_version = NULL,
system_prompt = NULL,
api_key = NULL,
credentials = NULL,
api_args = list(),
echo = c("none", "output", "all"),
api_headers = character(),
deployment_id = deprecated()
)
endpoint |
Azure OpenAI endpoint url with protocol and hostname, i.e.
|
model |
The deployment id for the model you want to use. |
params |
Common model parameters, usually created by |
api_version |
The API version to use. |
system_prompt |
A system prompt to set the behavior of the assistant. |
api_key |
|
credentials |
Override the default credentials. You generally should not need this argument; instead set the If you do need additional control, this argument takes a zero-argument function that returns either a string (the API key), or a named list (added as additional headers to every request). |
api_args |
Named list of arbitrary extra arguments appended to the body
of every chat API call. Combined with the body object generated by ellmer
with |
echo |
One of the following options:
Note this only affects the |
api_headers |
Named character vector of arbitrary extra headers appended to every chat API call. |
deployment_id |
A Chat object.
Other chatbots:
chat_anthropic(),
chat_aws_bedrock(),
chat_cloudflare(),
chat_databricks(),
chat_deepseek(),
chat_github(),
chat_google_gemini(),
chat_groq(),
chat_huggingface(),
chat_lmstudio(),
chat_mistral(),
chat_ollama(),
chat_openai(),
chat_openai_compatible(),
chat_openrouter(),
chat_perplexity(),
chat_portkey(),
chat_posit()
## Not run:
chat <- chat_azure_openai(model = "gpt-4o-mini")
chat$chat("Tell me three jokes about statisticians")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.