View source: R/provider-bedrock.R
| chat_bedrock | R Documentation |
AWS Bedrock provides a number of language models, including those from Anthropic's Claude, using the Bedrock Converse API.
Authentication is handled through {paws.common}, so if authentication
does not work for you automatically, you'll need to follow the advice
at https://www.paws-r-sdk.com/#credentials. In particular, if your
org uses AWS SSO, you'll need to run aws sso login at the terminal.
chat_bedrock(
system_prompt = NULL,
turns = NULL,
model = NULL,
profile = NULL,
api_args = list(),
echo = NULL
)
system_prompt |
A system prompt to set the behavior of the assistant. |
turns |
A list of Turns to start the chat with (i.e., continuing a previous conversation). If not provided, the conversation begins from scratch. |
model |
ellmer provides a default model, but you'll typically need to you'll specify a model that you actually have access to. If you're using cross-region inference,
you'll need to use the inference profile ID, e.g.
|
profile |
AWS profile to use. |
api_args |
Named list of arbitrary extra arguments appended to the body of every chat API call. Some useful arguments include: api_args = list(
inferenceConfig = list(
maxTokens = 100,
temperature = 0.7,
topP = 0.9,
topK = 20
)
)
|
echo |
One of the following options:
Note this only affects the |
A Chat object.
Other chatbots:
chat_claude(),
chat_cortex_analyst(),
chat_databricks(),
chat_deepseek(),
chat_gemini(),
chat_github(),
chat_groq(),
chat_ollama(),
chat_openai(),
chat_openrouter(),
chat_perplexity()
## Not run:
# Basic usage
chat <- chat_bedrock()
chat$chat("Tell me three jokes about statisticians")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.