View source: R/provider-databricks.R
| chat_databricks | R Documentation |
Databricks provides out-of-the-box access to a number of foundation models and can also serve as a gateway for external models hosted by a third party.
Built on top of chat_openai_compatible().
chat_databricks() picks up on ambient Databricks credentials for a subset
of the Databricks client unified authentication
model. Specifically, it supports:
Personal access tokens
Service principals via OAuth (OAuth M2M)
User account via OAuth (OAuth U2M)
Authentication via the Databricks CLI
Posit Workbench-managed credentials
Viewer-based credentials on Posit Connect. Requires the connectcreds package.
chat_databricks(
workspace = databricks_workspace(),
system_prompt = NULL,
model = NULL,
token = NULL,
params = NULL,
api_args = list(),
echo = c("none", "output", "all"),
api_headers = character()
)
workspace |
The URL of a Databricks workspace, e.g.
|
system_prompt |
A system prompt to set the behavior of the assistant. |
model |
The model to use for the chat (defaults to "databricks-claude-sonnet-4-6"). We regularly update the default, so we strongly recommend explicitly specifying a model for anything other than casual use. Available foundational models include:
|
token |
An authentication token for the Databricks workspace, or
|
params |
Common model parameters, usually created by |
api_args |
Named list of arbitrary extra arguments appended to the body
of every chat API call. Combined with the body object generated by ellmer
with |
echo |
One of the following options:
Note this only affects the |
api_headers |
Named character vector of arbitrary extra headers appended to every chat API call. |
A Chat object.
Other chatbots:
chat_anthropic(),
chat_aws_bedrock(),
chat_azure_openai(),
chat_cloudflare(),
chat_deepseek(),
chat_github(),
chat_google_gemini(),
chat_groq(),
chat_huggingface(),
chat_lmstudio(),
chat_mistral(),
chat_ollama(),
chat_openai(),
chat_openai_compatible(),
chat_openrouter(),
chat_perplexity(),
chat_portkey(),
chat_posit()
## Not run:
chat <- chat_databricks()
chat$chat("Tell me three jokes about statisticians")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.