View source: R/provider-perplexity.R
| chat_perplexity | R Documentation |
Sign up at https://www.perplexity.ai.
Perplexity AI is a platform for running LLMs that are capable of searching the web in real-time to help them answer questions with information that may not have been available when the model was trained.
This function is a Uses OpenAI compatible API via chat_openai_compatible() with
the defaults tweaked for Perplexity AI.
chat_perplexity(
system_prompt = NULL,
base_url = "https://api.perplexity.ai/",
api_key = NULL,
credentials = NULL,
model = NULL,
params = NULL,
api_args = list(),
echo = NULL,
api_headers = character()
)
system_prompt |
A system prompt to set the behavior of the assistant. |
base_url |
The base URL to the API endpoint. |
api_key |
|
credentials |
Override the default credentials. You generally should not need this argument; instead set the If you do need additional control, this argument takes a zero-argument function that returns either a string (the API key), or a named list (added as additional headers to every request). |
model |
The model to use for the chat (defaults to "sonar"). We regularly update the default, so we strongly recommend explicitly specifying a model for anything other than casual use. |
params |
Common model parameters, usually created by |
api_args |
Named list of arbitrary extra arguments appended to the body
of every chat API call. Combined with the body object generated by ellmer
with |
echo |
One of the following options:
Note this only affects the |
api_headers |
Named character vector of arbitrary extra headers appended to every chat API call. |
A Chat object.
Other chatbots:
chat_anthropic(),
chat_aws_bedrock(),
chat_azure_openai(),
chat_cloudflare(),
chat_databricks(),
chat_deepseek(),
chat_github(),
chat_google_gemini(),
chat_groq(),
chat_huggingface(),
chat_lmstudio(),
chat_mistral(),
chat_ollama(),
chat_openai(),
chat_openai_compatible(),
chat_openrouter(),
chat_portkey(),
chat_posit()
## Not run:
chat <- chat_perplexity()
chat$chat("Tell me three jokes about statisticians")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.