ellmer-package: ellmer: Chat with Large Language Models

ellmer-packageR Documentation

ellmer: Chat with Large Language Models

Description

logo

Chat with large language models from a range of providers including 'Claude' https://claude.ai, 'OpenAI' https://chatgpt.com, and more. Supports streaming, asynchronous calls, tool calling, and structured data extraction.

Author(s)

Maintainer: Hadley Wickham hadley@posit.co (ORCID)

Authors:

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also

Useful links:


ellmer documentation built on July 14, 2026, 1:07 a.m.