google_tool_web_fetch: Google URL fetch tool

View source: R/provider-google-tools.R

google_tool_web_fetchR Documentation

Google URL fetch tool

Description

When this tool is enabled, you can include URLs directly in your prompts and Gemini will fetch and analyze the content.

Learn more in https://ai.google.dev/gemini-api/docs/url-context.

Usage

google_tool_web_fetch()

See Also

Other built-in tools: claude_tool_web_fetch(), claude_tool_web_search(), google_tool_web_search(), openai_tool_web_search()

Examples

## Not run: 
chat <- chat_google_gemini()
chat$register_tool(google_tool_web_fetch())
chat$chat("What are the latest package releases on https://tidyverse.org/blog?")

## End(Not run)

ellmer documentation built on July 14, 2026, 1:07 a.m.