View source: R/provider-google-tools.R
| google_tool_web_search | R Documentation |
Enables Gemini models to search the web for up-to-date information and ground responses with citations to sources. The model automatically decides when (and how) to search the web based on your prompt. Search results are incorporated into the response with grounding metadata including source URLs and titles.
Learn more in https://ai.google.dev/gemini-api/docs/google-search.
google_tool_web_search()
Other built-in tools:
claude_tool_web_fetch(),
claude_tool_web_search(),
google_tool_web_fetch(),
openai_tool_web_search()
## Not run:
chat <- chat_google_gemini()
chat$register_tool(google_tool_web_search())
chat$chat("What was in the news today?")
chat$chat("What's the biggest news in the economy?")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.