View source: R/parallel-chat.R
| parallel_chat | R Documentation |
If you have multiple prompts, you can submit them in parallel. This is typically considerably faster than submitting them in sequence, especially with Gemini and OpenAI.
If you're using chat_openai() or chat_anthropic() and you're willing
to wait longer, you might want to use batch_chat() instead, as it comes
with a 50% discount in return for taking up to 24 hours.
parallel_chat(
chat,
prompts,
max_active = 10,
rpm = 500,
on_error = c("return", "continue", "stop")
)
parallel_chat_text(
chat,
prompts,
max_active = 10,
rpm = 500,
on_error = c("return", "continue", "stop")
)
parallel_chat_structured(
chat,
prompts,
type,
convert = TRUE,
include_tokens = FALSE,
include_cost = FALSE,
max_active = 10,
rpm = 500,
on_error = c("return", "continue", "stop")
)
chat |
A chat object created by a |
prompts |
A vector created by |
max_active |
The maximum number of simultaneous requests to send. For |
rpm |
Maximum number of requests per minute. |
on_error |
What to do when a request fails. One of:
|
type |
A type specification for the extracted data. Should be
created with a |
convert |
If |
include_tokens |
If |
include_cost |
If |
For parallel_chat(), a list with one element for each prompt. Each element
is either a Chat object (if successful), a NULL (if the request wasn't
performed) or an error object (if it failed).
For parallel_chat_text(), a character vector with one element for each
prompt. Requests that weren't succesful get an NA.
For parallel_chat_structured(), a single structured data object with one
element for each prompt. Typically, when type is an object, this will
be a tibble with one row for each prompt, and one column for each
property. If the output is a data frame, and some requests error,
an .error column will be added with the error objects.
chat <- chat_openai()
# Chat ----------------------------------------------------------------------
country <- c("Canada", "New Zealand", "Jamaica", "United States")
prompts <- interpolate("What's the capital of {{country}}?")
parallel_chat(chat, prompts)
# Structured data -----------------------------------------------------------
prompts <- list(
"I go by Alex. 42 years on this planet and counting.",
"Pleased to meet you! I'm Jamal, age 27.",
"They call me Li Wei. Nineteen years young.",
"Fatima here. Just celebrated my 35th birthday last week.",
"The name's Robert - 51 years old and proud of it.",
"Kwame here - just hit the big 5-0 this year."
)
type_person <- type_object(name = type_string(), age = type_number())
parallel_chat_structured(chat, prompts, type_person)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.