Skip to content

Call this function to find out the cumulative number of tokens that you have sent and recieved in the current session. The price will be shown if known.

Usage

token_usage()

Value

A data frame

Examples

token_usage()
#>    provider           model input output cached_input price
#> 1    OpenAI   gpt-5.6-terra   888    692            0 $0.01
#> 2 Anthropic claude-sonnet-5    19    270            0 $0.00