| type_boolean | R Documentation |
These functions specify object types in a way that chatbots understand and are used for tool calling and structured data extraction. Their names are based on the JSON schema, which is what the APIs expect behind the scenes. The translation from R concepts to these types is fairly straightforward.
type_boolean(), type_integer(), type_number(), and type_string()
each represent scalars. These are equivalent to length-1 logical,
integer, double, and character vectors (respectively).
type_enum() is equivalent to a length-1 factor; it is a string that can
only take the specified values.
type_array() is equivalent to a vector in R. You can use it to represent
an atomic vector: e.g. type_array(type_boolean()) is equivalent
to a logical vector and type_array(type_string()) is equivalent
to a character vector). You can also use it to represent a list of more
complicated types where every element is the same type (R has no base
equivalent to this), e.g. type_array(type_array(type_string()))
represents a list of character vectors.
type_object() is equivalent to a named list in R, but where every element
must have the specified type. For example,
type_object(a = type_string(), b = type_array(type_integer())) is
equivalent to a list with an element called a that is a string and
an element called b that is an integer vector.
type_ignore() is used in tool calling to indicate that an argument should
not be provided by the LLM. This is useful when the R function has a
default value for the argument and you don't want the LLM to supply it.
type_from_schema() allows you to specify the full schema that you want to
get back from the LLM as a JSON schema. This is useful if you have a
pre-defined schema that you want to use directly without manually creating
the type using the type_*() functions. You can point to a file with the
path argument or provide a JSON string with text. The schema must be a
valid JSON schema object.
type_boolean(description = NULL, required = TRUE)
type_integer(description = NULL, required = TRUE)
type_number(description = NULL, required = TRUE)
type_string(description = NULL, required = TRUE)
type_enum(values, description = NULL, required = TRUE)
type_array(items, description = NULL, required = TRUE)
type_object(
.description = NULL,
...,
.required = TRUE,
.additional_properties = deprecated()
)
type_from_schema(text, path)
type_ignore()
# An integer vector
type_array(type_integer())
# The closest equivalent to a data frame is an array of objects
type_array(type_object(
x = type_boolean(),
y = type_string(),
z = type_number()
))
# There's no specific type for dates, but you use a string with the
# requested format in the description (it's not guaranteed that you'll
# get this format back, but you should most of the time)
type_string("The creation date, in YYYY-MM-DD format.")
type_string("The update date, in dd/mm/yyyy format.")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.