A Provider captures the details of one chatbot service/API. This captures how the API works, not the details of the underlying large language model. Different providers might offer the same (open source) model behind a different API.
Arguments
- name
Name of the provider.
- base_url
The base URL for the API.
- extra_headers
Arbitrary extra headers to be added to the request.
- credentials
A zero-argument function that returns the credentials to use for authentication. Can either return a string, representing an API key, or a named list of headers.
- model, params, extra_args
These now live on the Model object; use
chat$get_model_object()instead.