View source: R/provider-google.R
| chat_google_gemini | R Documentation |
Google's AI offering is broken up into two parts: Gemini and Vertex AI. Most enterprises are likely to use Vertex AI, and individuals are likely to use Gemini.
Use google_upload() to upload files (PDFs, images, video, audio, etc.)
These functions try a number of authentication strategies, in this order:
An API key set in the GOOGLE_API_KEY or GEMINI_API_KEY env var
(Gemini only).
Google's default application credentials, if the gargle package is installed.
Viewer-based credentials on Posit Connect, if the connectcreds package.
. An browser-based OAuth flow, if
you're in an interactive session. This currently uses an unverified
OAuth app (so you will get a scary warning); we plan to verify in the
near future.
chat_google_gemini(
system_prompt = NULL,
base_url = "https://generativelanguage.googleapis.com/v1beta/",
api_key = NULL,
credentials = NULL,
model = NULL,
params = NULL,
api_args = list(),
api_headers = character(),
echo = NULL
)
chat_google_vertex(
location = Sys.getenv("GOOGLE_CLOUD_LOCATION"),
project_id = Sys.getenv("GOOGLE_CLOUD_PROJECT"),
system_prompt = NULL,
model = NULL,
params = NULL,
api_args = list(),
api_headers = character(),
echo = NULL
)
models_google_gemini(
base_url = "https://generativelanguage.googleapis.com/v1beta/",
api_key = NULL,
credentials = NULL
)
models_google_vertex(
location = Sys.getenv("GOOGLE_CLOUD_LOCATION"),
project_id = Sys.getenv("GOOGLE_CLOUD_PROJECT"),
credentials = NULL
)
system_prompt |
A system prompt to set the behavior of the assistant. |
base_url |
The base URL to the API endpoint. |
api_key |
|
credentials |
A function that returns a list of authentication headers
or |
model |
The model to use for the chat (defaults to "gemini-3.5-flash").
We regularly update the default, so we strongly recommend explicitly specifying a model for anything other than casual use.
Use |
params |
Common model parameters, usually created by |
api_args |
Named list of arbitrary extra arguments appended to the body
of every chat API call. Combined with the body object generated by ellmer
with |
api_headers |
Named character vector of arbitrary extra headers appended to every chat API call. |
echo |
One of the following options:
Note this only affects the |
location |
Location, e.g. |
project_id |
Project ID. |
A Chat object.
Other chatbots:
chat_anthropic(),
chat_aws_bedrock(),
chat_azure_openai(),
chat_cloudflare(),
chat_databricks(),
chat_deepseek(),
chat_github(),
chat_groq(),
chat_huggingface(),
chat_lmstudio(),
chat_mistral(),
chat_ollama(),
chat_openai(),
chat_openai_compatible(),
chat_openrouter(),
chat_perplexity(),
chat_portkey(),
chat_posit()
## Not run:
chat <- chat_google_gemini()
chat$chat("Tell me three jokes about statisticians")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.