View source: R/provider-google-tools.R
| google_tool_web_fetch | R Documentation |
When this tool is enabled, you can include URLs directly in your prompts and Gemini will fetch and analyze the content.
Learn more in https://ai.google.dev/gemini-api/docs/url-context.
google_tool_web_fetch()
Other built-in tools:
claude_tool_web_fetch(),
claude_tool_web_search(),
google_tool_web_search(),
openai_tool_web_search()
## Not run:
chat <- chat_google_gemini()
chat$register_tool(google_tool_web_fetch())
chat$chat("What are the latest package releases on https://tidyverse.org/blog?")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.